# Generated by Django 2.2.6 on 2019-10-17 16:46

from django.db import migrations, models
import django.db.models.deletion
import wagtailschemaorg.registry


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0041_group_collection_permissions_verbose_name_plural'),
        ('configuration', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='OrganizationInfoSettings',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(help_text="Your organization's public name", max_length=100, verbose_name='Name')),
                ('phone_number', models.CharField(blank=True, help_text='Public phone number', max_length=20, verbose_name='Phone number')),
                ('email', models.EmailField(blank=True, help_text='Public contact email', max_length=254, verbose_name='Email')),
                ('twitter_handle', models.CharField(blank=True, help_text='Without the @', max_length=15, verbose_name='Twitter handle')),
                ('facebook_url', models.URLField(blank=True, help_text="Page's url in facebook", verbose_name='Facebook')),
                ('twitter_url', models.URLField(blank=True, help_text="Page's url in twitter", verbose_name='Twitter')),
                ('instagram_url', models.URLField(blank=True, help_text="Page's url in instagram", verbose_name='Instagram')),
                ('linkedin_url', models.URLField(blank=True, help_text="Page's url in linkedin", verbose_name='LinkedIn')),
                ('youtube_url', models.URLField(blank=True, help_text="Page's url in youtube", verbose_name='Youtube')),
                ('vimeo_url', models.URLField(blank=True, help_text="Page's url in vimeo", verbose_name='Vimeo')),
                ('googleplus_url', models.URLField(blank=True, help_text="Page's url in google plus", verbose_name='Google Plus')),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site')),
            ],
            options={
                'verbose_name': 'Social',
                'verbose_name_plural': 'Social',
            },
            bases=(wagtailschemaorg.registry.SiteThingLD, models.Model),
        ),
        migrations.DeleteModel(
            name='SocialSettings',
        ),
    ]
