{% macro render(code) -%}
  <!-- CrazyEgg Code -->
  {% if code %}
    <script type="text/javascript" src="//script.crazyegg.com/pages/scripts/{{ code[:4] }}/{{ code[4:] }}.js" async="async"></script>
  {% else %}
    <!-- SEO-ALERT: No CrazyEgg ID was sent -->
  {% endif %}
{%- endmacro %}
