{% macro render_head(tag_id) %}
  <!-- Google Tag Manager -->
  {%- if tag_id -%}

    <script>(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':
    new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],
    j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src=
    'https://www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);
    })(window,document,'script','dataLayer','{{ tag_id }}');</script>
  {%- else -%}
    <!-- No Google Tag Manager ID -->
  {%- endif -%}
  <!-- End Google Tag Manager -->
{% endmacro %}

{% macro render_body(tag_id) %}
  <!-- Google Tag Manager (noscript) -->
  {%- if tag_id -%}
    <noscript>
      <iframe src="https://www.googletagmanager.com/ns.html?id={{ tag_id }}"
        height="0" width="0" style="display:none;visibility:hidden"></iframe>
    </noscript>
  {%- else -%}
    <!-- No Google Tag Manager ID -->
  {%- endif -%}
  <!-- End Google Tag Manager (noscript) -->
{% endmacro %}