{% macro website() -%}
  og: http://ogp.me/ns# fb: http://ogp.me/ns/fb#
{%- endmacro %}

{% macro article() -%}
  og: http://ogp.me/ns# fb: http://ogp.me/ns/fb#
{%- endmacro %}

{% macro music() -%}
  og: http://ogp.me/ns# fb: http://ogp.me/ns/fb# music: http://ogp.me/ns/music#
{%- endmacro %}

{% macro video() -%}
  og: http://ogp.me/ns# fb: http://ogp.me/ns/fb# video: http://ogp.me/ns/video#
{%- endmacro %}

{% macro book() -%}
  og: http://ogp.me/ns# fb: http://ogp.me/ns/fb# book: http://ogp.me/ns/book#
{%- endmacro %}

{% macro profile() -%}
  og: http://ogp.me/ns# fb: http://ogp.me/ns/fb# profile: http://ogp.me/ns/profile#
{%- endmacro %}
