{% extends "base_error.html" %}
{% set page_title ='Oops, algo salio mal. 500 / No encontré la página que estas buscando.' %}
{% block content %}
    <div class="content">
        <a href="/">
            <img src="{{ static('404.svg') }}">
        </a>
    </div>
{% endblock %}
