{% macro render(code) -%}
  <!-- CrazyEgg Code -->
  {% if code %}
    <meta name="ahrefs-site-verification" content="{{ code }}">
  {% else %}
    <!-- SEO-ALERT: No CrazyEgg ID was sent -->
  {% endif %}
{%- endmacro %}
